Index: /trunk/MagicSoft/Mars/Changelog
===================================================================
--- /trunk/MagicSoft/Mars/Changelog	(revision 5409)
+++ /trunk/MagicSoft/Mars/Changelog	(revision 5410)
@@ -25,4 +25,16 @@
    * mmc/MMcEvt.hxx
      - Added comment regarding change in version 4.
+
+   * mmc/MMcFadcHeader.hxx
+     - Added data member fNoiseGainFluctuations. Updated class version
+       to 6
+
+   * mmc/MMcTrigHeader.hxx
+     - Added data members fGainFluctuations and fNoiseGainFluctuations.
+       Will contain same values as the corresponding members in the
+       MMcFadcHeader of MC camera files. We just put them in both 
+       headers because the fluctuations affect both the trigger 
+       signal and the FADC signal.
+
 
  2004/11/16: Markus Gaug
Index: /trunk/MagicSoft/include-Classes/MMcFormat/MMcTrigHeader.hxx
===================================================================
--- /trunk/MagicSoft/include-Classes/MMcFormat/MMcTrigHeader.hxx	(revision 5409)
+++ /trunk/MagicSoft/include-Classes/MMcFormat/MMcTrigHeader.hxx	(revision 5410)
@@ -8,4 +8,9 @@
 #include "MTriggerDefine.h"
 #include "Mdefine.h"
+
+//
+// Version 4
+//   Added data members fGainFluctuations and fNoiseGainFluctuations
+//
 
 class MMcTrigHeader : public MParContainer{
@@ -31,4 +36,13 @@
                             // the amplitude of the single phe response 
                             // for the trigger
+
+  Bool_t  fGainFluctuations;
+  // kTRUE if PMT gain fluctuations were simulated for the signal 
+  // (=> default in camera simulation)
+
+  Bool_t  fNoiseGainFluctuations;
+  // kTRUE if PMT gain fluctuations were simulated for the NSB noise 
+  // (=> default in StarResponse program)
+
 
  public:
@@ -90,5 +104,6 @@
   }
 
-
+  void SetGainFluctuations(Bool_t x) { fGainFluctuations = x; }
+  void SetNoiseGainFluctuations(Bool_t x) { fNoiseGainFluctuations = x; }
 
   Short_t GetMultiplicity() { return fMultiplicity; }
@@ -111,8 +126,7 @@
 
 
-  ClassDef(MMcTrigHeader, 3)  //Stores Montecarlo Information which describes the used trigger
+  ClassDef(MMcTrigHeader, 4)  //Stores Montecarlo Information which describes the used trigger
 
 };
 
 #endif
-

Index: /trunk/MagicSoft/include-Classes/MMcFormat/MMcFadcHeader.hxx
===================================================================
--- /trunk/MagicSoft/include-Classes/MMcFormat/MMcFadcHeader.hxx	(revision 5409)
+++ /trunk/MagicSoft/include-Classes/MMcFormat/MMcFadcHeader.hxx	(revision 5410)
@@ -7,4 +7,12 @@
 
 #include "MFadcDefine.h"
+
+//
+// Version 5:
+//   Added member fGainFluctuations
+//
+// Version 6:
+//   Added member fNoiseGainFluctuations
+//
 
 class MMcFadcHeader : public MParContainer{
@@ -53,5 +61,10 @@
 
   Bool_t  fGainFluctuations;
-  // kTRUE if PMT gain fluctuations were simulated (=> default in camera simulation)
+  // kTRUE if PMT gain fluctuations were simulated for the signal 
+  // (=> default in camera simulation)
+
+  Bool_t  fNoiseGainFluctuations;
+  // kTRUE if PMT gain fluctuations were simulated for the NSB noise 
+  // (=> default in StarResponse program)
 
 
@@ -105,4 +118,5 @@
   
   void SetGainFluctuations(Bool_t x) { fGainFluctuations = x; }
+  void SetNoiseGainFluctuations(Bool_t x) { fNoiseGainFluctuations = x; }
 
   Float_t GetPedestal(UInt_t i) const    { return fPedesMean[i]; }
@@ -117,5 +131,5 @@
   UInt_t GetNumPixel() const { return MFADC_CHANNELS; }
 
-  ClassDef(MMcFadcHeader, 5)  //Stores Montecarlo Information describing the FADC behaviour
+  ClassDef(MMcFadcHeader, 6)  //Stores Montecarlo Information describing the FADC behaviour
 
 };